@@ -4,7 +4,7 @@
  *
  *			  set of Query/Expr walkers
  *
- * by Pavel Stehule 2013-2021
+ * by Pavel Stehule 2013-2022
  *
  *-------------------------------------------------------------------------
  */
@@ -28,9 +28,6 @@ typedef struct
 	char *query_str;
 } check_funcexpr_walker_params;
 
-typedef bool (*check_function_callback) (Oid func_id, void *context);
-
-
 static int check_fmt_string(const char *fmt,
 							List *args,
 							int location,
@@ -76,6 +73,17 @@ detect_dependency_walker(Node *node, void *context)
 			}
 		}
 
+#if PG_VERSION_NUM >= 110000
+
+		if (query->utilityStmt && IsA(query->utilityStmt, CallStmt))
+		{
+			CallStmt *callstmt = (CallStmt *) query->utilityStmt;
+
+			detect_dependency_walker((Node *) callstmt->funcexpr, context);
+		}
+
+#endif
+
 		return query_tree_walker((Query *) node,
 								 detect_dependency_walker,
 								 context, 0);
@@ -93,6 +101,12 @@ detect_dependency_walker(Node *node, void *context)
 				ListCell		   *lc;
 				int		i = 0;
 
+#if PG_VERSION_NUM >= 110000
+
+				char		prokind = get_func_prokind(fexpr->funcid);
+
+#endif
+
 				initStringInfo(&str);
 				appendStringInfoChar(&str, '(');
 				foreach(lc, fexpr->args)
@@ -106,6 +120,17 @@ detect_dependency_walker(Node *node, void *context)
 				}
 				appendStringInfoChar(&str, ')');
 
+#if PG_VERSION_NUM >= 110000
+
+				plpgsql_check_put_dependency(ri,
+											  prokind == PROKIND_PROCEDURE ? "PROCEDURE" : "FUNCTION",
+											  fexpr->funcid,
+											  get_namespace_name(get_func_namespace(fexpr->funcid)),
+											  get_func_name(fexpr->funcid),
+											  str.data);
+
+#else
+
 				plpgsql_check_put_dependency(ri,
 											  "FUNCTION",
 											  fexpr->funcid,
@@ -113,6 +138,8 @@ detect_dependency_walker(Node *node, void *context)
 											  get_func_name(fexpr->funcid),
 											  str.data);
 
+#endif
+
 				pfree(str.data);
 
 				cstate->func_oids = bms_add_member(cstate->func_oids, fexpr->funcid);
@@ -1031,12 +1058,16 @@ contain_mutable_functions_walker(Node *node, void *context)
 								context))
 		return true;
 
+#if PG_VERSION_NUM < 160000
+
 	if (IsA(node, SQLValueFunction))
 	{
 		/* all variants of SQLValueFunction are stable */
 		return true;
 	}
 
+#endif
+
 	if (IsA(node, NextValueExpr))
 	{
 		/* NextValueExpr is volatile */
